==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/hierarchy.js <==
var hierarchy =
[
    [ "<NSCopying>", null, [
      [ "TNKCoordinatePoint", "interface_t_n_k_coordinate_point.html", [
        [ "TNKSearchNavPoint", "interface_t_n_k_search_nav_point.html", null ]
      ] ],
      [ "TNKDriveRouteSearchOption", "interface_t_n_k_drive_route_search_option.html", null ],
      [ "TNKEnlargedMapConfig", "interface_t_n_k_enlarged_map_config.html", [
        [ "TNKTravelEnlargedMapConfig", "interface_t_n_k_travel_enlarged_map_config.html", null ]
      ] ],
      [ "TNKRoutePoint", "interface_t_n_k_route_point.html", null ],
      [ "TNKSearchNavPoint", "interface_t_n_k_search_nav_point.html", null ],
      [ "TNKTruckSearchOption", "interface_t_n_k_truck_search_option.html", null ]
    ] ],
    [ "NSObject", null, [
      [ "TNKAudioParam", "interface_t_n_k_audio_param.html", null ],
      [ "TNKBaseNavManager", "interface_t_n_k_base_nav_manager.html", [
        [ "TNKDriveNavManager", "interface_t_n_k_drive_nav_manager.html", null ],
        [ "TNKRideNavManager", "interface_t_n_k_ride_nav_manager.html", null ],
        [ "TNKWalkNavManager", "interface_t_n_k_walk_nav_manager.html", null ]
      ] ],
      [ "TNKChangeRouteMsg", "interface_t_n_k_change_route_msg.html", null ],
      [ "TNKCoordinatePoint", "interface_t_n_k_coordinate_point.html", null ],
      [ "TNKCustomRouteReason", "interface_t_n_k_custom_route_reason.html", null ],
      [ "TNKDriveNavRoute", "interface_t_n_k_drive_nav_route.html", null ],
      [ "TNKDriveNavigationData", "interface_t_n_k_drive_navigation_data.html", null ],
      [ "TNKDriveRerouteResult", "interface_t_n_k_drive_reroute_result.html", null ],
      [ "TNKDriveRoute", "interface_t_n_k_drive_route.html", null ],
      [ "TNKDriveRouteExplain", "interface_t_n_k_drive_route_explain.html", null ],
      [ "TNKDriveRoutePlanService", "interface_t_n_k_drive_route_plan_service.html", null ],
      [ "TNKDriveRouteSearchOption", "interface_t_n_k_drive_route_search_option.html", null ],
      [ "TNKDriveRouteSearchResult", "interface_t_n_k_drive_route_search_result.html", null ],
      [ "TNKEnlargedMapConfig", "interface_t_n_k_enlarged_map_config.html", null ],
      [ "TNKForkPoint", "interface_t_n_k_fork_point.html", null ],
      [ "TNKGpsStatus", "interface_t_n_k_gps_status.html", null ],
      [ "TNKHighwayFacilityInfo", "interface_t_n_k_highway_facility_info.html", null ],
      [ "TNKHighwayFacilityItem", "interface_t_n_k_highway_facility_item.html", null ],
      [ "TNKIdleSectionInfo", "interface_t_n_k_idle_section_info.html", null ],
      [ "TNKLaneInfo", "interface_t_n_k_lane_info.html", null ],
      [ "TNKLocation", "interface_t_n_k_location.html", null ],
      [ "TNKLocationAdapter", "interface_t_n_k_location_adapter.html", null ],
      [ "TNKLocationListenerConfig", "interface_t_n_k_location_listener_config.html", null ],
      [ "TNKLogger", "interface_t_n_k_logger.html", null ],
      [ "TNKLoggerRefluxOptions", "interface_t_n_k_logger_reflux_options.html", null ],
      [ "TNKMathTool", "interface_t_n_k_math_tool.html", null ],
      [ "TNKNavCameraInfo", "interface_t_n_k_nav_camera_info.html", null ],
      [ "TNKNavRestrictionInfo", "interface_t_n_k_nav_restriction_info.html", null ],
      [ "TNKNavRestrictionItem", "interface_t_n_k_nav_restriction_item.html", [
        [ "TNKTruckNavRestrictionItem", "interface_t_n_k_truck_nav_restriction_item.html", null ],
        [ "TNKTurnNavRestrictionItem", "interface_t_n_k_turn_nav_restriction_item.html", null ]
      ] ],
      [ "TNKNavRoadMatchResult", "interface_t_n_k_nav_road_match_result.html", null ],
      [ "TNKNavServices", "interface_t_n_k_nav_services.html", null ],
      [ "TNKNavStartFailInfo", "interface_t_n_k_nav_start_fail_info.html", null ],
      [ "TNKNavTTS", "interface_t_n_k_nav_t_t_s.html", null ],
      [ "TNKNavToWayPointInfo", "interface_t_n_k_nav_to_way_point_info.html", null ],
      [ "TNKODMarkerPresentation", "interface_t_n_k_o_d_marker_presentation.html", null ],
      [ "TNKParallelRoadStatus", "interface_t_n_k_parallel_road_status.html", null ],
      [ "TNKPosMatchLocation", "interface_t_n_k_pos_match_location.html", null ],
      [ "TNKRecommendRouteInfo", "interface_t_n_k_recommend_route_info.html", null ],
      [ "TNKRedLineConfig", "interface_t_n_k_red_line_config.html", null ],
      [ "TNKRerouteParam", "interface_t_n_k_reroute_param.html", [
        [ "TNKDestAndWaypointRerouteParam", "interface_t_n_k_dest_and_waypoint_reroute_param.html", null ],
        [ "TNKDestinationRerouteParam", "interface_t_n_k_destination_reroute_param.html", null ],
        [ "TNKParallelRoadRerouteParam", "interface_t_n_k_parallel_road_reroute_param.html", null ],
        [ "TNKRefreshRerouteParam", "interface_t_n_k_refresh_reroute_param.html", null ],
        [ "TNKRestoreRouteRerouteParam", "interface_t_n_k_restore_route_reroute_param.html", null ],
        [ "TNKSearchPreferenceRerouteParam", "interface_t_n_k_search_preference_reroute_param.html", null ],
        [ "TNKWaypointRerouteParam", "interface_t_n_k_waypoint_reroute_param.html", null ]
      ] ],
      [ "TNKRestrictionItem", "interface_t_n_k_restriction_item.html", [
        [ "TNKTruckRestrictionItem", "interface_t_n_k_truck_restriction_item.html", null ],
        [ "TNKTurnRestrictionItem", "interface_t_n_k_turn_restriction_item.html", null ]
      ] ],
      [ "TNKRideNavRoute", "interface_t_n_k_ride_nav_route.html", null ],
      [ "TNKRideNavigationData", "interface_t_n_k_ride_navigation_data.html", null ],
      [ "TNKRideRerouteResult", "interface_t_n_k_ride_reroute_result.html", null ],
      [ "TNKRideRoute", "interface_t_n_k_ride_route.html", null ],
      [ "TNKRideRouteSearchResult", "interface_t_n_k_ride_route_search_result.html", null ],
      [ "TNKRouteColorPalette", "interface_t_n_k_route_color_palette.html", null ],
      [ "TNKRouteConfig", "interface_t_n_k_route_config.html", null ],
      [ "TNKRouteFilterLink", "interface_t_n_k_route_filter_link.html", null ],
      [ "TNKRouteLineConfig", "interface_t_n_k_route_line_config.html", null ],
      [ "TNKRouteMilestone", "interface_t_n_k_route_milestone.html", null ],
      [ "TNKRoutePoint", "interface_t_n_k_route_point.html", null ],
      [ "TNKRouteRequest", "interface_t_n_k_route_request.html", [
        [ "TNKDriveRouteRequest", "interface_t_n_k_drive_route_request.html", null ]
      ] ],
      [ "TNKRouteTrafficItem", "interface_t_n_k_route_traffic_item.html", null ],
      [ "TNKSearchTask", "interface_t_n_k_search_task.html", null ],
      [ "TNKSegmentItem", "interface_t_n_k_segment_item.html", null ],
      [ "TNKSegmentRoadName", "interface_t_n_k_segment_road_name.html", null ],
      [ "TNKSpeedMonitorStatus", "interface_t_n_k_speed_monitor_status.html", null ],
      [ "TNKTollStationInfo", "interface_t_n_k_toll_station_info.html", null ],
      [ "TNKTollStationItem", "interface_t_n_k_toll_station_item.html", null ],
      [ "TNKTrafficJamInfo", "interface_t_n_k_traffic_jam_info.html", null ],
      [ "TNKTrafficLightCountdownMsg", "interface_t_n_k_traffic_light_countdown_msg.html", null ],
      [ "TNKTravelNavigationData", "interface_t_n_k_travel_navigation_data.html", null ],
      [ "TNKTruckSearchOption", "interface_t_n_k_truck_search_option.html", null ],
      [ "TNKTurnArrowConfig", "interface_t_n_k_turn_arrow_config.html", null ],
      [ "TNKUIComponentConfig", "interface_t_n_k_u_i_component_config.html", null ],
      [ "TNKUserLocationConfig", "interface_t_n_k_user_location_config.html", null ],
      [ "TNKUserLocationPresentation", "interface_t_n_k_user_location_presentation.html", null ],
      [ "TNKWalkNavRoute", "interface_t_n_k_walk_nav_route.html", null ],
      [ "TNKWalkNavigationData", "interface_t_n_k_walk_navigation_data.html", null ],
      [ "TNKWalkRerouteResult", "interface_t_n_k_walk_reroute_result.html", null ],
      [ "TNKWalkRoute", "interface_t_n_k_walk_route.html", null ],
      [ "TNKWalkRouteSearchResult", "interface_t_n_k_walk_route_search_result.html", null ],
      [ "TNKWaypointMarkerPresentation", "interface_t_n_k_waypoint_marker_presentation.html", null ]
    ] ],
    [ "<NSObject>", null, [
      [ "<TNKAudioPlayerDelegate>", "protocol_t_n_k_audio_player_delegate-p.html", null ],
      [ "<TNKAudioPlayerProtocol>", "protocol_t_n_k_audio_player_protocol-p.html", null ],
      [ "<TNKBaseNavViewDelegate>", "protocol_t_n_k_base_nav_view_delegate-p.html", [
        [ "<TNKDriveNavViewDelegate>", "protocol_t_n_k_drive_nav_view_delegate-p.html", null ],
        [ "<TNKRideNavViewDelegate>", "protocol_t_n_k_ride_nav_view_delegate-p.html", null ],
        [ "<TNKWalkNavViewDelegate>", "protocol_t_n_k_walk_nav_view_delegate-p.html", null ]
      ] ],
      [ "<TNKCustomAreaViewDelegate>", "protocol_t_n_k_custom_area_view_delegate-p.html", null ],
      [ "<TNKDriveNavDataSource>", "protocol_t_n_k_drive_nav_data_source-p.html", null ],
      [ "<TNKDriveNavDelegate>", "protocol_t_n_k_drive_nav_delegate-p.html", [
        [ "TNKDriveNavView", "interface_t_n_k_drive_nav_view.html", null ],
        [ "TNKNaviTrafficBarWidget", "interface_t_n_k_navi_traffic_bar_widget.html", null ],
        [ "TNKTravelNavView", "interface_t_n_k_travel_nav_view.html", null ]
      ] ],
      [ "<TNKLocationSimulator>", "protocol_t_n_k_location_simulator-p.html", null ],
      [ "<TNKRideNavDataSource>", "protocol_t_n_k_ride_nav_data_source-p.html", null ],
      [ "<TNKRideNavDelegate>", "protocol_t_n_k_ride_nav_delegate-p.html", [
        [ "TNKRideNavView", "interface_t_n_k_ride_nav_view.html", null ]
      ] ],
      [ "<TNKWalkNavDataSource>", "protocol_t_n_k_walk_nav_data_source-p.html", null ],
      [ "<TNKWalkNavDelegate>", "protocol_t_n_k_walk_nav_delegate-p.html", [
        [ "TNKWalkNavView", "interface_t_n_k_walk_nav_view.html", null ]
      ] ]
    ] ],
    [ "QMapView(TNKExtesion)", "category_q_map_view_07_t_n_k_extesion_08.html", null ],
    [ "<TencentLBSLocationManagerDelegate>", null, [
      [ "<TNKPosMatchLocationListener>", "protocol_t_n_k_pos_match_location_listener-p.html", null ]
    ] ],
    [ "TNKBaseNavView(QMapView)", "category_t_n_k_base_nav_view_07_q_map_view_08.html", null ],
    [ "UIView", null, [
      [ "TNKBaseNavView", "interface_t_n_k_base_nav_view.html", [
        [ "TNKDriveNavView", "interface_t_n_k_drive_nav_view.html", null ],
        [ "TNKRideNavView", "interface_t_n_k_ride_nav_view.html", null ],
        [ "TNKTravelNavView", "interface_t_n_k_travel_nav_view.html", null ],
        [ "TNKWalkNavView", "interface_t_n_k_walk_nav_view.html", null ]
      ] ],
      [ "TNKCustomAreaView", "interface_t_n_k_custom_area_view.html", null ],
      [ "TNKNaviTrafficBarWidget", "interface_t_n_k_navi_traffic_bar_widget.html", null ]
    ] ]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/hierarchy.js <==
var hierarchy =
[
    [ "<NSCopying>", null, [
      [ "TNKCoordinatePoint", "interface_t_n_k_coordinate_point.html", [
        [ "TNKSearchNavPoint", "interface_t_n_k_search_nav_point.html", null ]
      ] ],
      [ "TNKDriveRouteSearchOption", "interface_t_n_k_drive_route_search_option.html", null ],
      [ "TNKEnlargedMapConfig", "interface_t_n_k_enlarged_map_config.html", [
        [ "TNKTravelEnlargedMapConfig", "interface_t_n_k_travel_enlarged_map_config.html", null ]
      ] ],
      [ "TNKMotoSearchOption", "interface_t_n_k_moto_search_option.html", null ],
      [ "TNKRoutePoint", "interface_t_n_k_route_point.html", null ],
      [ "TNKSearchNavPoint", "interface_t_n_k_search_nav_point.html", null ],
      [ "TNKTruckSearchOption", "interface_t_n_k_truck_search_option.html", null ]
    ] ],
    [ "NSObject", null, [
      [ "TNKAudioParam", "interface_t_n_k_audio_param.html", null ],
      [ "TNKBaseNavManager", "interface_t_n_k_base_nav_manager.html", [
        [ "TNKDriveNavManager", "interface_t_n_k_drive_nav_manager.html", null ],
        [ "TNKRideNavManager", "interface_t_n_k_ride_nav_manager.html", null ],
        [ "TNKWalkNavManager", "interface_t_n_k_walk_nav_manager.html", null ]
      ] ],
      [ "TNKChangeRouteMsg", "interface_t_n_k_change_route_msg.html", null ],
      [ "TNKCoordinatePoint", "interface_t_n_k_coordinate_point.html", null ],
      [ "TNKCustomRouteReason", "interface_t_n_k_custom_route_reason.html", null ],
      [ "TNKDriveNavRoute", "interface_t_n_k_drive_nav_route.html", null ],
      [ "TNKDriveNavigationData", "interface_t_n_k_drive_navigation_data.html", null ],
      [ "TNKDriveRerouteResult", "interface_t_n_k_drive_reroute_result.html", null ],
      [ "TNKDriveRoute", "interface_t_n_k_drive_route.html", null ],
      [ "TNKDriveRouteExplain", "interface_t_n_k_drive_route_explain.html", null ],
      [ "TNKDriveRoutePlanService", "interface_t_n_k_drive_route_plan_service.html", null ],
      [ "TNKDriveRouteSearchOption", "interface_t_n_k_drive_route_search_option.html", null ],
      [ "TNKDriveRouteSearchResult", "interface_t_n_k_drive_route_search_result.html", null ],
      [ "TNKEnlargedMapConfig", "interface_t_n_k_enlarged_map_config.html", null ],
      [ "TNKForkPoint", "interface_t_n_k_fork_point.html", null ],
      [ "TNKGpsStatus", "interface_t_n_k_gps_status.html", null ],
      [ "TNKHighwayFacilityInfo", "interface_t_n_k_highway_facility_info.html", null ],
      [ "TNKHighwayFacilityItem", "interface_t_n_k_highway_facility_item.html", null ],
      [ "TNKIdleSectionInfo", "interface_t_n_k_idle_section_info.html", null ],
      [ "TNKLaneInfo", "interface_t_n_k_lane_info.html", null ],
      [ "TNKLocation", "interface_t_n_k_location.html", null ],
      [ "TNKLocationAdapter", "interface_t_n_k_location_adapter.html", null ],
      [ "TNKLocationListenerConfig", "interface_t_n_k_location_listener_config.html", null ],
      [ "TNKLogger", "interface_t_n_k_logger.html", null ],
      [ "TNKLoggerRefluxOptions", "interface_t_n_k_logger_reflux_options.html", null ],
      [ "TNKMathTool", "interface_t_n_k_math_tool.html", null ],
      [ "TNKMotoSearchOption", "interface_t_n_k_moto_search_option.html", null ],
      [ "TNKNavCameraInfo", "interface_t_n_k_nav_camera_info.html", null ],
      [ "TNKNavRestrictionInfo", "interface_t_n_k_nav_restriction_info.html", null ],
      [ "TNKNavRestrictionItem", "interface_t_n_k_nav_restriction_item.html", [
        [ "TNKTruckNavRestrictionItem", "interface_t_n_k_truck_nav_restriction_item.html", null ],
        [ "TNKTurnNavRestrictionItem", "interface_t_n_k_turn_nav_restriction_item.html", null ]
      ] ],
      [ "TNKNavRoadMatchResult", "interface_t_n_k_nav_road_match_result.html", null ],
      [ "TNKNavServices", "interface_t_n_k_nav_services.html", null ],
      [ "TNKNavStartFailInfo", "interface_t_n_k_nav_start_fail_info.html", null ],
      [ "TNKNavTTS", "interface_t_n_k_nav_t_t_s.html", null ],
      [ "TNKNavToWayPointInfo", "interface_t_n_k_nav_to_way_point_info.html", null ],
      [ "TNKODMarkerPresentation", "interface_t_n_k_o_d_marker_presentation.html", null ],
      [ "TNKParallelRoadStatus", "interface_t_n_k_parallel_road_status.html", null ],
      [ "TNKPosMatchLocation", "interface_t_n_k_pos_match_location.html", null ],
      [ "TNKRecommendRouteInfo", "interface_t_n_k_recommend_route_info.html", null ],
      [ "TNKRedLineConfig", "interface_t_n_k_red_line_config.html", null ],
      [ "TNKRerouteParam", "interface_t_n_k_reroute_param.html", [
        [ "TNKDestAndWaypointRerouteParam", "interface_t_n_k_dest_and_waypoint_reroute_param.html", null ],
        [ "TNKDestinationRerouteParam", "interface_t_n_k_destination_reroute_param.html", null ],
        [ "TNKOffCourseRerouteParam", "interface_t_n_k_off_course_reroute_param.html", null ],
        [ "TNKParallelRoadRerouteParam", "interface_t_n_k_parallel_road_reroute_param.html", null ],
        [ "TNKRefreshRerouteParam", "interface_t_n_k_refresh_reroute_param.html", null ],
        [ "TNKRestoreRouteRerouteParam", "interface_t_n_k_restore_route_reroute_param.html", null ],
        [ "TNKSearchPreferenceRerouteParam", "interface_t_n_k_search_preference_reroute_param.html", null ],
        [ "TNKWaypointRerouteParam", "interface_t_n_k_waypoint_reroute_param.html", null ]
      ] ],
      [ "TNKRestrictionItem", "interface_t_n_k_restriction_item.html", [
        [ "TNKTruckRestrictionItem", "interface_t_n_k_truck_restriction_item.html", null ],
        [ "TNKTurnRestrictionItem", "interface_t_n_k_turn_restriction_item.html", null ]
      ] ],
      [ "TNKRideNavRoute", "interface_t_n_k_ride_nav_route.html", null ],
      [ "TNKRideNavigationBriefInfo", "interface_t_n_k_ride_navigation_brief_info.html", null ],
      [ "TNKRideNavigationBriefInfoData", "interface_t_n_k_ride_navigation_brief_info_data.html", null ],
      [ "TNKRideNavigationData", "interface_t_n_k_ride_navigation_data.html", null ],
      [ "TNKRideRerouteResult", "interface_t_n_k_ride_reroute_result.html", null ],
      [ "TNKRideRoute", "interface_t_n_k_ride_route.html", null ],
      [ "TNKRideRouteSearchResult", "interface_t_n_k_ride_route_search_result.html", null ],
      [ "TNKRouteColorPalette", "interface_t_n_k_route_color_palette.html", null ],
      [ "TNKRouteConfig", "interface_t_n_k_route_config.html", null ],
      [ "TNKRouteFilterLink", "interface_t_n_k_route_filter_link.html", null ],
      [ "TNKRouteLineConfig", "interface_t_n_k_route_line_config.html", null ],
      [ "TNKRouteMilestone", "interface_t_n_k_route_milestone.html", null ],
      [ "TNKRoutePoint", "interface_t_n_k_route_point.html", null ],
      [ "TNKRouteRequest", "interface_t_n_k_route_request.html", [
        [ "TNKDriveRouteRequest", "interface_t_n_k_drive_route_request.html", null ]
      ] ],
      [ "TNKRouteTrafficItem", "interface_t_n_k_route_traffic_item.html", null ],
      [ "TNKSearchTask", "interface_t_n_k_search_task.html", null ],
      [ "TNKSegmentItem", "interface_t_n_k_segment_item.html", null ],
      [ "TNKSegmentRoadName", "interface_t_n_k_segment_road_name.html", null ],
      [ "TNKSnapShotConfig", "interface_t_n_k_snap_shot_config.html", null ],
      [ "TNKSnapShotResult", "interface_t_n_k_snap_shot_result.html", null ],
      [ "TNKSpeedMonitorStatus", "interface_t_n_k_speed_monitor_status.html", null ],
      [ "TNKTollStationInfo", "interface_t_n_k_toll_station_info.html", null ],
      [ "TNKTollStationItem", "interface_t_n_k_toll_station_item.html", null ],
      [ "TNKTrafficJamInfo", "interface_t_n_k_traffic_jam_info.html", null ],
      [ "TNKTrafficLightCountdownMsg", "interface_t_n_k_traffic_light_countdown_msg.html", null ],
      [ "TNKTravelNavigationData", "interface_t_n_k_travel_navigation_data.html", null ],
      [ "TNKTruckSearchOption", "interface_t_n_k_truck_search_option.html", null ],
      [ "TNKTurnArrowConfig", "interface_t_n_k_turn_arrow_config.html", null ],
      [ "TNKUIComponentConfig", "interface_t_n_k_u_i_component_config.html", null ],
      [ "TNKUserLocationConfig", "interface_t_n_k_user_location_config.html", null ],
      [ "TNKUserLocationPresentation", "interface_t_n_k_user_location_presentation.html", null ],
      [ "TNKWalkNavRoute", "interface_t_n_k_walk_nav_route.html", null ],
      [ "TNKWalkNavigationData", "interface_t_n_k_walk_navigation_data.html", null ],
      [ "TNKWalkRerouteResult", "interface_t_n_k_walk_reroute_result.html", null ],
      [ "TNKWalkRoute", "interface_t_n_k_walk_route.html", null ],
      [ "TNKWalkRouteSearchResult", "interface_t_n_k_walk_route_search_result.html", null ],
      [ "TNKWaypointMarkerPresentation", "interface_t_n_k_waypoint_marker_presentation.html", null ]
    ] ],
    [ "<NSObject>", null, [
      [ "<TNKAudioPlayerDelegate>", "protocol_t_n_k_audio_player_delegate-p.html", null ],
      [ "<TNKAudioPlayerProtocol>", "protocol_t_n_k_audio_player_protocol-p.html", null ],
      [ "<TNKBaseNavViewDelegate>", "protocol_t_n_k_base_nav_view_delegate-p.html", [
        [ "<TNKDriveNavViewDelegate>", "protocol_t_n_k_drive_nav_view_delegate-p.html", null ],
        [ "<TNKRideNavViewDelegate>", "protocol_t_n_k_ride_nav_view_delegate-p.html", null ],
        [ "<TNKWalkNavViewDelegate>", "protocol_t_n_k_walk_nav_view_delegate-p.html", null ]
      ] ],
      [ "<TNKCustomAreaViewDelegate>", "protocol_t_n_k_custom_area_view_delegate-p.html", null ],
      [ "<TNKDriveNavDataSource>", "protocol_t_n_k_drive_nav_data_source-p.html", null ],
      [ "<TNKDriveNavDelegate>", "protocol_t_n_k_drive_nav_delegate-p.html", [
        [ "TNKDriveNavView", "interface_t_n_k_drive_nav_view.html", null ],
        [ "TNKNaviTrafficBarWidget", "interface_t_n_k_navi_traffic_bar_widget.html", null ],
        [ "TNKTravelNavView", "interface_t_n_k_travel_nav_view.html", null ]
      ] ],
      [ "<TNKLocationSimulator>", "protocol_t_n_k_location_simulator-p.html", null ],
      [ "<TNKRideNavDataSource>", "protocol_t_n_k_ride_nav_data_source-p.html", null ],
      [ "<TNKRideNavDelegate>", "protocol_t_n_k_ride_nav_delegate-p.html", [
        [ "TNKRideNavView", "interface_t_n_k_ride_nav_view.html", null ]
      ] ],
      [ "<TNKWalkNavDataSource>", "protocol_t_n_k_walk_nav_data_source-p.html", null ],
      [ "<TNKWalkNavDelegate>", "protocol_t_n_k_walk_nav_delegate-p.html", [
        [ "TNKWalkNavView", "interface_t_n_k_walk_nav_view.html", null ]
      ] ]
    ] ],
    [ "QMapView(TNKExtesion)", "category_q_map_view_07_t_n_k_extesion_08.html", null ],
    [ "<TencentLBSLocationManagerDelegate>", null, [
      [ "<TNKPosMatchLocationListener>", "protocol_t_n_k_pos_match_location_listener-p.html", null ]
    ] ],
    [ "TNKBaseNavView(QMapView)", "category_t_n_k_base_nav_view_07_q_map_view_08.html", null ],
    [ "UIView", null, [
      [ "TNKBaseNavView", "interface_t_n_k_base_nav_view.html", [
        [ "TNKDriveNavView", "interface_t_n_k_drive_nav_view.html", null ],
        [ "TNKRideNavView", "interface_t_n_k_ride_nav_view.html", null ],
        [ "TNKTravelNavView", "interface_t_n_k_travel_nav_view.html", null ],
        [ "TNKWalkNavView", "interface_t_n_k_walk_nav_view.html", null ]
      ] ],
      [ "TNKCustomAreaView", "interface_t_n_k_custom_area_view.html", null ],
      [ "TNKNaviTrafficBarWidget", "interface_t_n_k_navi_traffic_bar_widget.html", null ]
    ] ]
];
